package com.ellismarkov;

import android.app.Activity;
import android.opengl.GLES20;
import android.opengl.GLSurfaceView;
import android.opengl.Matrix;
import android.util.Log;

import javax.microedition.khronos.egl.EGLConfig;
import javax.microedition.khronos.opengles.GL10;

/**
 * GLES20Renderer: the OGLES 2.0 Thread.
 */
public class GLES20Renderer implements GLSurfaceView.Renderer {

    public final static int MAX_POINTS = 30000;

    private Activity mActivity;

    private GLSLProgram mProgramme1;

    private Vertices mVertices;

    private Timer mTimer;



    GLES20Renderer(Activity activity) {
        mActivity = activity;
        mTimer = new Timer();
    }

    @Override
    public void onSurfaceCreated(GL10 gl, EGLConfig eglConfig) {
        // create a GLSLProgram
        mProgramme1 = new GLSLProgram(mActivity, "pointsprite");
        // build the program
        mProgramme1.make();

        // Vertices is our 3D object. It contains vertices and indices
        mVertices = new Vertices();

        for (int i=0; i < MAX_POINTS; i++) {
            // create a vertex
            P3FT2FR4FVertex v = new P3FT2FR4FVertex();
            v.setPos(getRamdom()*80.f, getRamdom()*80.f, 0);
            v.setColor(getRamdom(), getRamdom(), getRamdom(), 1.f);
            mVertices.putVertice(i, v);
            mVertices.putIndice(i, i);
        }

    }

    @Override
    public void onSurfaceChanged(GL10 gl, int width, int height) {
        GLES20.glViewport(0, 0, width, height);
    }

    @Override
    public void onDrawFrame(GL10 gl) {
        mTimer.addMark();
        mTimer.logFPS();

        GLES20.glClearColor(0.0f, 0.0f, 0.0f, 1.0f);
        GLES20.glClear(GLES20.GL_COLOR_BUFFER_BIT);

        mProgramme1.use();
        mProgramme1.draw(mVertices, GLES20.GL_POINTS, MAX_POINTS);
    }

    private void checkGlError(String op) {
        int error;
        while ((error = GLES20.glGetError()) != GLES20.GL_NO_ERROR) {
            Log.e("EllisMarkov", op + ": glError " + error);
        }
    }

    private float getRamdom() {
        float value = (float) (Math.random() * 2. - 1.);
        return value;
    }
}
